AiSensitiveClassifier class abstract

Implementers

Constructors

AiSensitiveClassifier()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

analyseIsSensitiveContent({Uint8List? receiptImageBytes, String text = ''}) Future
analyseIsSensitiveContentFromImage({required Image image, String text = ''}) Future<AiClassificationResponse?>
analyseIsSensitiveContentFromImageProvider({required ImageProvider<Object> imageProvider, String text = ''}) Future<AiClassificationResponse?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited