AiClassificationResponse class

Constructors

AiClassificationResponse({required String imageClassification, required String textClassification, required bool isSensitive})
AiClassificationResponse.fromJson(String source)
factory
AiClassificationResponse.fromMap(Map<String, dynamic> map)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
imageClassification String
final
isSensitive bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
textClassification String
final

Methods

copyWith({String? imageClassification, String? textClassification, bool? isSensitive}) AiClassificationResponse
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited