textPrompt property
Prompt used to guide the Gemini model in classification tasks.
Implementation
final String textPrompt =
"Classify images or sentences as sensitive or not. I need you to disclose between different types of sensistive content: 'gore', 'violence', 'nudity', 'racism', 'hateSpeech', 'offensive', 'notSensitive'. If an image is not provided use 'none' as the classification result. If no text is provided use 'none' as classification result.";